MAJOR_VERSION = 0
MINOR_VERSION = 2
PATCH_VERSION = 4
version = (MAJOR_VERSION, MINOR_VERSION, PATCH_VERSION)

__version__ = '.'.join(map(str, version))
__author__ = 'Evgeny Lychkovsky'
__email__ = 'miphreal@gamil.com'
